aboutsummaryrefslogtreecommitdiffhomepage
path: root/hugolib/hugo_sites_build.go
diff options
context:
space:
mode:
Diffstat (limited to 'hugolib/hugo_sites_build.go')
-rw-r--r--hugolib/hugo_sites_build.go18
1 files changed, 14 insertions, 4 deletions
diff --git a/hugolib/hugo_sites_build.go b/hugolib/hugo_sites_build.go
index 5346e2e6b..02ecd5785 100644
--- a/hugolib/hugo_sites_build.go
+++ b/hugolib/hugo_sites_build.go
@@ -738,15 +738,15 @@ type pathChange struct {
// The path to the changed file.
p *paths.Path
- // If true, this is a delete operation (a delete or a rename).
- delete bool
+ // If true, this is a structural change (e.g. a delete or a rename).
+ structural bool
// If true, this is a directory.
isDir bool
}
func (p pathChange) isStructuralChange() bool {
- return p.delete || p.isDir
+ return p.structural || p.isDir
}
func (h *HugoSites) processPartialRebuildChanges(ctx context.Context, l logg.LevelLogger, config *BuildCfg) error {
@@ -912,7 +912,7 @@ func (h *HugoSites) processPartialFileEvents(ctx context.Context, l logg.LevelLo
}
}
- addedOrChangedContent = append(addedOrChangedContent, pathChange{p: pathInfo, delete: delete, isDir: isDir})
+ addedOrChangedContent = append(addedOrChangedContent, pathChange{p: pathInfo, structural: delete, isDir: isDir})
case files.ComponentFolderLayouts:
tmplChanged = true
@@ -1033,6 +1033,16 @@ func (h *HugoSites) processPartialFileEvents(ctx context.Context, l logg.LevelLo
handleChange(id, false, true)
}
+ for _, id := range changes {
+ if id == identity.GenghisKhan {
+ for i, cp := range addedOrChangedContent {
+ cp.structural = true
+ addedOrChangedContent[i] = cp
+ }
+ break
+ }
+ }
+
resourceFiles := h.fileEventsContentPaths(addedOrChangedContent)
changed := &WhatChanged{